==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm2015/lib/igr-radial-pie-series.js <==
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialPieSeries } from "./RadialPieSeries";
/**
 * Represents a IgxDataChartComponent radial pie series.
 * Compare values across categories by using radial pie slices.
*/
export class IgrRadialPieSeries extends IgrAnchoredRadialSeries {
    createImplementation() {
        return new RadialPieSeries();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets whether the current series shows a pie shape.
    */
    get isPie() {
        return this.i.e0;
    }
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    get isMarkerlessDisplayPreferred() {
        return this.i.ey;
    }
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusX() {
        return this.i.ya;
    }
    set radiusX(v) {
        this.i.ya = +v;
    }
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusY() {
        return this.i.yb;
    }
    set radiusY(v) {
        this.i.yb = +v;
    }
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan() {
        let iv = this.i.h0();
        return (iv);
    }
}

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm2015/lib/igr-radial-pie-series.js <==
import { LegendEmptyValuesMode_$type } from "igniteui-react-core";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialPieSeries } from "./RadialPieSeries";
import { ensureEnum, toPoint, fromRect } from "igniteui-react-core";
/**
 * Represents a IgxDataChartComponent radial pie series.
 * Compare values across categories by using radial pie slices.
*/
export class IgrRadialPieSeries extends IgrAnchoredRadialSeries {
    createImplementation() {
        return new RadialPieSeries();
    }
    /**
                                 * @hidden
                                 */
    get i() {
        return this._implementation;
    }
    constructor(props) {
        super(props);
    }
    /**
     * Gets whether the current series shows a pie shape.
    */
    get isPie() {
        return this.i.fm;
    }
    /**
     * Overridden by derived series classes to indicate when marker-less display is preferred or not.
    */
    get isMarkerlessDisplayPreferred() {
        return this.i.fk;
    }
    /**
     * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusX() {
        return this.i.adq;
    }
    set radiusX(v) {
        this.i.adq = +v;
    }
    /**
     * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
    */
    get radiusY() {
        return this.i.adr;
    }
    set radiusY(v) {
        this.i.adr = +v;
    }
    /**
     * Gets or sets the property name that contains the legend labels.
    */
    get legendLabelMemberPath() {
        return this.i.adv;
    }
    set legendLabelMemberPath(v) {
        this.i.adv = v;
    }
    /**
     * Determines display mode for zero values in the legend.
    */
    get legendEmptyValuesMode() {
        return this.i.adl;
    }
    set legendEmptyValuesMode(v) {
        this.i.adl = ensureEnum(LegendEmptyValuesMode_$type, v);
    }
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    getItemSpan() {
        let iv = this.i.iv();
        return (iv);
    }
    getSeriesValueBoundingBox(world) {
        let iv = this.i.wj(toPoint(world));
        return fromRect(iv);
    }
}
